@@ -1,8 +1,23 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * callbacks.h
+ *  Authors: Iain Holmes <iain@ximian.com>
+ *
+ *  Copyright 2001 Iain Holmes
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- * Copyright (C) 2001 Iain Holmes
- * Authors: Iain Holmes  <iain@ximian.com>
  */
 
 #ifndef __CALLBACKS_H__
@@ -68,15 +83,13 @@ void position_slider_leave (GtkRange *range,
 			    GdkEventCrossing *event,
 			    GnomeCD *gcd);
 
-gboolean tray_icon_clicked (GtkWidget *widget,
-                           GdkEventButton *event,
-                           GnomeCD *gcd);
+void tray_popup_menu_cb (GtkStatusIcon *icon,
+			 guint          button,
+			 guint          activate_time,
+			 GnomeCD       *gcd);
+void tray_icon_activated (GtkStatusIcon *icon,
+			  GnomeCD *gcd);
 
-gboolean tray_icon_pressed (GtkWidget *widget,
-                           GdkEventKey *event,
-                           GnomeCD *gcd);
-gint tray_icon_expose (GtkWidget* widget,
-                      GdkEventExpose *event);
 gboolean button_press_event_cb (GtkWidget *widget,
 	                      GdkEventButton *event,
 	                      GnomeCD *gcd);
